@@ -1,4 +1,4 @@
-/*      $Id: placement.c 29512 2009-02-18 22:17:27Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
         MA 02110-1301, USA.
 
 
-        xfwm4    - (c) 2002-2009 Olivier Fourdan
+        xfwm4    - (c) 2002-2011 Olivier Fourdan
 
  */
 
@@ -99,7 +99,8 @@ void
 clientMaxSpace (ScreenInfo *screen_info, int *x, int *y, int *w, int *h)
 {
     Client *c2;
-    int i, delta, screen_width, screen_height;
+    guint i;
+    gint delta, screen_width, screen_height;
 
     g_return_if_fail (x != NULL);
     g_return_if_fail (y != NULL);
@@ -162,7 +163,8 @@ clientCkeckTitle (Client * c)
 {
     Client *c2;
     ScreenInfo *screen_info;
-    int i, frame_x, frame_y, frame_width, frame_top;
+    guint i;
+    gint frame_x, frame_y, frame_width, frame_top;
 
     frame_x = frameX (c);
     frame_y = frameY (c);
@@ -196,11 +198,12 @@ clientConstrainPos (Client * c, gboolean show_full)
 {
     Client *c2;
     ScreenInfo *screen_info;
-    int i, cx, cy, disp_x, disp_y, disp_max_x, disp_max_y;
-    int frame_height, frame_width, frame_top, frame_left;
-    int frame_x, frame_y, frame_visible;
-    int screen_width, screen_height;
-    unsigned int ret;
+    guint i;
+    gint cx, cy, disp_x, disp_y, disp_max_x, disp_max_y;
+    gint frame_height, frame_width, frame_top, frame_left;
+    gint frame_x, frame_y, frame_visible;
+    gint screen_width, screen_height;
+    guint ret;
     GdkRectangle rect;
     gint min_visible;
 
@@ -538,8 +541,9 @@ smartPlacement (Client * c, int full_x, int full_y, int full_w, int full_h)
     Client *c2;
     ScreenInfo *screen_info;
     gfloat best_overlaps;
-    int test_x, test_y, xmax, ymax, best_x, best_y, i;
-    int frame_x, frame_y, frame_height, frame_width, frame_left, frame_top;
+    guint i;
+    gint test_x, test_y, xmax, ymax, best_x, best_y;
+    gint frame_x, frame_y, frame_height, frame_width, frame_left, frame_top;
     gboolean first;
 
     g_return_if_fail (c != NULL);
@@ -660,7 +664,7 @@ clientInitPosition (Client * c)
     msy = 0;
     position = (c->size->flags & (PPosition | USPosition));
 
-    n_monitors = gdk_screen_get_n_monitors (c->screen_info->gscr);
+    n_monitors = myScreenGetNumMonitors (c->screen_info);
     if ((n_monitors > 1) || (screen_info->params->placement_mode == PLACE_MOUSE))
     {
         getMouseXY (screen_info, screen_info->xroot, &msx, &msy);
@@ -756,8 +760,9 @@ clientFill (Client * c, int fill_type)
     GdkRectangle rect;
     XWindowChanges wc;
     unsigned short mask;
-    int i, cx, cy, full_x, full_y, full_w, full_h;
-    int tmp_x, tmp_y, tmp_w, tmp_h;
+    guint i;
+    gint cx, cy, full_x, full_y, full_w, full_h;
+    gint tmp_x, tmp_y, tmp_w, tmp_h;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientFill");
@@ -792,7 +797,7 @@ clientFill (Client * c, int fill_type)
                  */
                 if (segment_overlap (frameY(c), frameY(c) + frameHeight(c), frameY(c2), frameY(c2) + frameHeight(c2)))
                 {
-                    if ((frameX(c2) + frameWidth(c2)) < frameX(c))
+                    if ((frameX(c2) + frameWidth(c2)) <= frameX(c))
                     {
                         if (west_neighbour)
                         {
@@ -809,7 +814,7 @@ clientFill (Client * c, int fill_type)
                             west_neighbour = c2;
                         }
                     }
-                    if ((frameX(c) + frameWidth(c)) < frameX(c2))
+                    if ((frameX(c) + frameWidth(c)) <= frameX(c2))
                     {
                         /* Check if c2 is closer to the client
                          * then the west neighbour already found
@@ -837,7 +842,7 @@ clientFill (Client * c, int fill_type)
                  */
                 if (segment_overlap (frameX(c), frameX(c) + frameWidth(c), frameX(c2), frameX(c2) + frameWidth(c2)))
                 {
-                    if ((frameY(c2) + frameHeight(c2)) < frameY(c))
+                    if ((frameY(c2) + frameHeight(c2)) <= frameY(c))
                     {
                         if (north_neighbour)
                         {
@@ -854,7 +859,7 @@ clientFill (Client * c, int fill_type)
                             north_neighbour = c2;
                         }
                     }
-                    if ((frameY(c) + frameHeight(c)) < frameY(c2))
+                    if ((frameY(c) + frameHeight(c)) <= frameY(c2))
                     {
                         if (south_neighbour)
                         {
